@@ -1,9 +1,7 @@
 /*
-    $Id: avc.h 214 2011-02-02 16:51:31Z marc.noirot $
+    FLVMeta - FLV Metadata Editor
 
-    FLV Metadata updater
-
-    Copyright (C) 2007-2011 Marc Noirot <marc.noirot AT gmail.com>
+    Copyright (C) 2007-2013 Marc Noirot <marc.noirot AT gmail.com>
 
     This file is part of FLVMeta.
 
@@ -19,7 +17,7 @@
 
     You should have received a copy of the GNU General Public License
     along with FLVMeta; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 */
 #ifndef __AVC_H__
 #define __AVC_H__
