@@ -1,9 +1,7 @@
 /*
-    $Id: dump_json.h 231 2011-06-27 13:46:19Z marc.noirot $
+    FLVMeta - FLV Metadata Editor
 
-    FLV Metadata updater
-
-    Copyright (C) 2007-2011 Marc Noirot <marc.noirot AT gmail.com>
+    Copyright (C) 2007-2013 Marc Noirot <marc.noirot AT gmail.com>
 
     This file is part of FLVMeta.
 
@@ -32,7 +30,7 @@ extern "C" {
 
 /* JSON dumping functions */
 void dump_json_setup_metadata_dump(flv_parser * parser);
-void dump_json_setup_file_dump(flv_parser * parser);
+int dump_json_file(flv_parser * parser, const flvmeta_opts * options);
 int dump_json_amf_data(const amf_data * data);
 
 #ifdef __cplusplus
