@@ -1,9 +1,7 @@
 /*
-    $Id: dump_raw.h 229 2011-06-16 09:44:05Z marc.noirot $
+    FLVMeta - FLV Metadata Editor
 
-    FLV Metadata updater
-
-    Copyright (C) 2007-2011 Marc Noirot <marc.noirot AT gmail.com>
+    Copyright (C) 2007-2013 Marc Noirot <marc.noirot AT gmail.com>
 
     This file is part of FLVMeta.
 
@@ -19,7 +17,7 @@
 
     You should have received a copy of the GNU General Public License
     along with FLVMeta; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 */
 #ifndef __DUMP_RAW_H__
 #define __DUMP_RAW_H__
@@ -32,7 +30,7 @@ extern "C" {
 
 /* raw dumping functions */
 void dump_raw_setup_metadata_dump(flv_parser * parser);
-void dump_raw_setup_file_dump(flv_parser * parser);
+int dump_raw_file(flv_parser * parser, const flvmeta_opts * options);
 int dump_raw_amf_data(const amf_data * data);
 
 #ifdef __cplusplus
