@@ -1,9 +1,7 @@
 /*
-    $Id: dump_xml.h 216 2011-02-11 16:38:59Z marc.noirot $
+    FLVMeta - FLV Metadata Editor
 
-    FLV Metadata updater
-
-    Copyright (C) 2007-2011 Marc Noirot <marc.noirot AT gmail.com>
+    Copyright (C) 2007-2013 Marc Noirot <marc.noirot AT gmail.com>
 
     This file is part of FLVMeta.
 
@@ -19,7 +17,7 @@
 
     You should have received a copy of the GNU General Public License
     along with FLVMeta; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 */
 #ifndef __DUMP_XML_H__
 #define __DUMP_XML_H__
@@ -31,9 +29,9 @@ extern "C" {
 #endif /* __cplusplus */
 
 /* XML dumping functions */
-extern void dump_xml_setup_metadata_dump(flv_parser * parser);
-extern void dump_xml_setup_file_dump(flv_parser * parser);
-extern int dump_xml_amf_data(const amf_data * data);
+void dump_xml_setup_metadata_dump(flv_parser * parser);
+int dump_xml_file(flv_parser * parser, const flvmeta_opts * options);
+int dump_xml_amf_data(const amf_data * data);
 
 #ifdef __cplusplus
 }
