@@ -1,9 +1,7 @@
 /*
-    $Id: dump_yaml.h 231 2011-06-27 13:46:19Z marc.noirot $
+    FLVMeta - FLV Metadata Editor
 
-    FLV Metadata updater
-
-    Copyright (C) 2007-2011 Marc Noirot <marc.noirot AT gmail.com>
+    Copyright (C) 2007-2013 Marc Noirot <marc.noirot AT gmail.com>
 
     This file is part of FLVMeta.
 
@@ -31,9 +29,9 @@ extern "C" {
 #endif /* __cplusplus */
 
 /* YAML dumping functions */
-extern void dump_yaml_setup_metadata_dump(flv_parser * parser);
-extern void dump_yaml_setup_file_dump(flv_parser * parser);
-extern int dump_yaml_amf_data(const amf_data * data);
+void dump_yaml_setup_metadata_dump(flv_parser * parser);
+int dump_yaml_file(flv_parser * parser, const flvmeta_opts * options);
+int dump_yaml_amf_data(const amf_data * data);
 
 #ifdef __cplusplus
 }
